summaryrefslogtreecommitdiff
path: root/src/wx/config_dialog.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/wx/config_dialog.h')
-rw-r--r--src/wx/config_dialog.h25
1 files changed, 23 insertions, 2 deletions
diff --git a/src/wx/config_dialog.h b/src/wx/config_dialog.h
index f6f3b3707..526480912 100644
--- a/src/wx/config_dialog.h
+++ b/src/wx/config_dialog.h
@@ -18,7 +18,7 @@
*/
/** @file src/config_dialog.h
* @brief A dialogue to edit DVD-o-matic configuration.
*/
#include <wx/wx.h>
@@ -27,11 +27,12 @@
#include <wx/filepicker.h>
class DirPickerCtrl;
+class wxNotebook;
class ServerDescription;
/** @class ConfigDialog
* @brief A dialogue to edit DVD-o-matic configuration.
*/
class ConfigDialog : public wxDialog
{
@@ -55,12 +56,30 @@ private:
void edit_server_clicked (wxCommandEvent &);
void remove_server_clicked (wxCommandEvent &);
void server_selection_changed (wxListEvent &);
+ void default_format_changed (wxCommandEvent &);
+ void default_dcp_content_type_changed (wxCommandEvent &);
+ void issuer_changed (wxCommandEvent &);
+ void creator_changed (wxCommandEvent &);
void add_server_to_control (ServerDescription *);
void setup_language_sensitivity ();
+ void make_misc_panel ();
+ void make_tms_panel ();
+ void make_metadata_panel ();
+ void make_ab_panel ();
+ void make_servers_panel ();
+
+ wxNotebook* _notebook;
+ wxPanel* _misc_panel;
+ wxPanel* _tms_panel;
+ wxPanel* _ab_panel;
+ wxPanel* _servers_panel;
+ wxPanel* _metadata_panel;
wxCheckBox* _set_language;
wxChoice* _language;
+ wxChoice* _default_format;
+ wxChoice* _default_dcp_content_type;
wxTextCtrl* _tms_ip;
wxTextCtrl* _tms_path;
wxTextCtrl* _tms_user;
@@ -79,5 +98,7 @@ private:
wxButton* _add_server;
wxButton* _edit_server;
wxButton* _remove_server;
+ wxTextCtrl* _issuer;
+ wxTextCtrl* _creator;
};
@@ -18,7 +18,7 @@
*/
/** @file src/config_dialog.h
- * @brief A dialogue to edit DVD-o-matic configuration.
+ * @brief A dialogue to edit DCP-o-matic configuration.
*/
#include <wx/wx.h>
@@ -27,11 +27,12 @@
class ServerDescription;
/** @class ConfigDialog
- * @brief A dialogue to edit DVD-o-matic configuration.
+ * @brief A dialogue to edit DCP-o-matic configuration.
*/
class ConfigDialog : public wxDialog